@@ -1,2 +1,2 @@
-from atmos_cloud_sim_uj_utils import show_plot
+from open_atmos_jupyter_utils import show_plot
 from .nondivergent_vector_field_2d import nondivergent_vector_field_2d
