@@ -67,11 +67,15 @@ def test_todos_annotated(file, gh_issues):  # pylint: disable=redefined-outer-na
             continue
         match = re.search(r'TODO #(\d+)', line)
         if match is None:
-            raise Exception(f"TODO not annotated with issue id ({line})")
+            raise AssertionError(f"TODO not annotated with issue id ({line})")
         giving_up_with_hope_other_builds_did_it = len(gh_issues) == 0
         if not giving_up_with_hope_other_builds_did_it:
             number = int(match.group(1))
             if number not in gh_issues.keys():
-                raise Exception(f"TODO annotated with non-existent id ({line})")
+                raise AssertionError(
+                    f"TODO annotated with non-existent id ({line})"
+                )
             if gh_issues[number] != 'open':
-                raise Exception(f"TODO remains for a non-open issue ({line})")
+                raise AssertionError(
+                    f"TODO remains for a non-open issue ({line})"
+                )
